from django.db import models
from django.contrib.auth.models import User
from django.conf import settings

from image.models import Disk
from image.models import Image
from interface_openstack.implementation.storage.openstack_snapshot_manager import SnapshotManager 


class BaseTemplate(models.Model):

    """Virtual machine template.
    """

    name = models.CharField(
        max_length=100,
        verbose_name="name",
        help_text="Human readable name of template."
    )
    description = models.TextField(
        verbose_name="description",
        blank=True,
        help_text="Description of the template."
    )
    remote_ID = models.CharField(
        max_length=40,
        unique=True,
        verbose_name="remote_ID",
        help_text="ID, which helps access the template."
    )
    created_at = models.DateTimeField(
        auto_now_add=True,
        editable=False,
        help_text="Date, when the template created."
    )
    created_by = models.ForeignKey(
        User,
        on_delete=models.DO_NOTHING,
        related_name=("created_templates")
    )
    # lease
    # flavour
    



class Template(BaseTemplate):
    disk = models.ForeignKey(
        Disk,
        related_name="templates",
        on_delete=models.CASCADE,
        help_text="The disk where the template is located."
    )

    @classmethod
    def create_from_volume(cls, name, description, disk, user):
        interface = SnapshotManager(settings.CONNECTION)
        remote_template = interface.create_from_volume(disk.remote_ID)
        remote_id = remote_template.id
        new_template = cls.object.create(
            name=name,
            description=description,
            disk=disk,
            remote_ID=remote_id,
            created_by=user
        )
        return new_template

    
class PureTemplate(BaseTemplate):
    images = models.ForeignKey(
        Image,
        related_name="templates",
        on_delete=models.CASCADE
    )
